#
# spec file for package gtkmm2-documentation
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   gtkmm-documentation
Name:           gtkmm2-documentation
Version:        2.24.1
Release:        bp153.1.14
Summary:        C++ Bindings for GTK+ -- Documentation
License:        GFDL-1.2-only AND GPL-2.0-or-later
Group:          Documentation/Other
URL:            http://www.gnome.org
Source:         %{_name}-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(giomm-2.4)
BuildRequires:  pkgconfig(gtkmm-2.4)
Recommends:     %{name}-lang
BuildArch:      noarch

%description
Gtkmm provides a C++ interface to the GTK+ GUI library. gtkmm wraps
GTK+. Highlights include typesafe callbacks, widgets extensible via
inheritance, and a comprehensive set of widget classes that can be
freely combined to quickly create complex user interfaces.

%package -n gtkmm2-tutorial
Summary:        C++ Bindings for GTK+ -- Tutorial
Group:          Documentation/Other
Requires:       gtkmm2-doc
Supplements:    gtkmm2-doc
Conflicts:      gtkmm3-tutorial
Provides:       %{name} = %{version}

%description -n gtkmm2-tutorial
Gtkmm provides a C++ interface to the GTK+ GUI library. gtkmm wraps
GTK+. Highlights include typesafe callbacks, widgets extensible via
inheritance, and a comprehensive set of widget classes that can be
freely combined to quickly create complex user interfaces.

%lang_package -n gtkmm2-tutorial

%prep
%setup -q -n %{_name}-%{version}

%build
%configure\
	--disable-scrollkeeper
make %{?_smp_mflags}

%install
%make_install
# Drop html version: the docbook version is more than enough
rm -r %{buildroot}%{_datadir}/doc/gtkmm-2.4/tutorial/html
mv %{buildroot}/%{_datadir}/gnome/help/gtkmm-tutorial/ %{buildroot}/%{_datadir}/gnome/help/gtkmm-tutorial2/

%files -n gtkmm2-tutorial
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/gtkmm-tutorial2/
%doc %{_datadir}/gnome/help/gtkmm-tutorial2/C/

%files -n gtkmm2-tutorial-lang
%doc %{_datadir}/gnome/help/gtkmm-tutorial2/de/
%doc %{_datadir}/gnome/help/gtkmm-tutorial2/es/

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Jun  2 2013 varkoly@suse.com
- Fix spec to avoid conflict between gtkmm2-tutorial-lang gtkmm3-tutorial-lang
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Tue Jun 28 2011 vuntz@opensuse.org
- Update to version 2.24.1:
  + Put a 2 in the name, so this is now Programming with gtkmm 2.
- Changes from version 2.24.0:
  + Replace mentions of the deprecated ComboBoxEntry with CombBox
    plus has-entry.
  + Add Gtk::Tooltip example.
  + Build: Check for mm-common.
- Changes from version 2.23.0:
  + Adapted to recent API deprecations in gtkmm 2.23/24.
* Fri May 27 2011 vuntz@opensuse.org
- Rename gtkmm-documentation source package to gtkmm2-documentation
  as gtkmm-documentation now tracks gtkmm3.
- Change packaging to be as close as possible as the
  gtkmm-documentation one:
  + Replace glibmm2-devel and gtkmm2-devel BuildRequires with
    pkgconfig(giomm-2.4) and pkgconfig(gtkmm-2.4).
  + Stop shipping the HTML-generated version of the doc: we're
    completely happy with having the docbook version, as it's visible
    in yelp.
  + Add gtkmm2-documentation Provides to gtkmm2-tutorial.
  + Update descriptions.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec 15 2010 vuntz@opensuse.org
- Own /usr/share/doc/packages/gtkmm2, /usr/share/gnome and
  /usr/share/gnome/help to fix build.
* Fri Oct 29 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Make the API reference links go to /stable instead of
    /unstable, to avoid sending people to the (different) gtkmm 3
    API.
  + Example code links: Use the gtkmm-2-22 branch instead of
    master, to avoid sending people to the examples for the gtkmm 3
    API.
* Tue Sep 21 2010 vuntz@opensuse.org
- Update to version 2.21.8.1:
  + Builds with the latest gtkmm-2.4 (2.21.8.1) release.
  + Improve the Assistant example.
  + Buttons chapter: Remove text about non-existant XPMLabelBox
    class.
  + Recommend non-deprecated Tooltip API in Tooltips chapter.
  + Remove the optional API appendix, because it is not supported
    in recent gtkmm versions.
  + Remove use of reduced API.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.20.1:
  + Multiple-Item Widgets chapter: Added Assistant sub-section.
* Mon Mar 29 2010 vuntz@opensuse.org
- New package.
